cuda_ml_cache_clean: Remove cuda.ml native-backend caches

View source: R/runtime.R

cuda_ml_cache_cleanR Documentation

Remove cuda.ml native-backend caches

Description

Removes downloaded and source-built runtime and backend cache generations, including the selected-backend record. Restart R before calling this function if the native backend has been loaded in this process.

Usage

cuda_ml_cache_clean()

Value

Invisibly returns TRUE.


cuda.ml documentation built on Aug. 21, 2026, 9:14 a.m.