cuda_ml_fil_enabled: Determine whether Forest Inference Library (FIL)...

cuda_ml_fil_enabledR Documentation

Determine whether Forest Inference Library (FIL) functionalities are enabled in the current installation of {cuda.ml}.

Description

CuML Forest Inference Library (FIL) functionalities (see https://github.com/rapidsai/cuml/tree/main/python/cuml/fil#readme) will require Treelite C API. If you need FIL to run tree-based model ensemble on GPU, and fil_enabled() returns FALSE, then please consider installing Treelite and then re-installing {cuda.ml}.

Usage

cuda_ml_fil_enabled()

Value

A logical value indicating whether the Forest Inference Library (FIL) functionalities are enabled.

Examples

if (cuda_ml_fil_enabled()) {
  # run GPU-accelerated Forest Inference Library (FIL) functionalities
} else {
  message(
    "FIL functionalities are disabled in the current installation of ",
    "{cuda.ml}. Please reinstall Treelite C library first, and then re-install",
    " {cuda.ml} to enable FIL."
  )
}

cuda.ml documentation built on April 29, 2026, 5:10 p.m.