cuda_ml_is_classifier: Determine whether a CuML model is a classifier.

View source: R/model.R

cuda_ml_is_classifierR Documentation

Determine whether a CuML model is a classifier.

Description

Given a trained CuML model, return TRUE if the model is a classifier, otherwise FALSE (e.g., if the model is a regressor).

Usage

cuda_ml_is_classifier(model)

Arguments

model

A trained CuML model.

Value

A logical value indicating whether the model is a classifier.


cuda.ml documentation built on April 29, 2026, 5:10 p.m.