Build a specification for the "ivfflat" KNN query algorithm.
Source:R/knn.R
cuda_ml_knn_algo_ivfflat.RdBuild a specification of the flat-inverted-file KNN query algorithm, with all required parameters specified explicitly.
R/knn.R
cuda_ml_knn_algo_ivfflat.RdBuild a specification of the flat-inverted-file KNN query algorithm, with all required parameters specified explicitly.