cuda_ml_knn_algo_ivfsq: Build a specification for the "ivfsq" KNN query algorithm.

View source: R/knn.R

cuda_ml_knn_algo_ivfsqR Documentation

Build a specification for the "ivfsq" KNN query algorithm.

Description

Build a specification of the inverted-file-scalar-quantization KNN query algorithm, with all required parameters specified explicitly.

Usage

cuda_ml_knn_algo_ivfsq(
  nlist,
  nprobe,
  qtype = c("QT_8bit", "QT_4bit", "QT_8bit_uniform", "QT_4bit_uniform", "QT_fp16",
    "QT_8bit_direct", "QT_6bit"),
  encode_residual = FALSE
)

Arguments

nlist

Number of cells to partition dataset into.

nprobe

At query time, the number of cells used for approximate nearest neighbor search.

qtype

Quantizer type. Must be one of {"QT_8bit", "QT_4bit", "QT_8bit_uniform", "QT_4bit_uniform", "QT_fp16", "QT_8bit_direct", "QT_6bit"}.

encode_residual

Whether to encode residuals.

Value

An object encapsulating all required parameters of the "ivfsq" KNN query algorithm.


cuda.ml documentation built on April 29, 2026, 5:10 p.m.