has_cuML: Determine whether {cuda.ml} was linked to a valid version of...

has_cuMLR Documentation

Determine whether {cuda.ml} was linked to a valid version of the RAPIDS cuML shared library.

Description

Determine whether {cuda.ml} was linked to a valid version of the RAPIDS cuML shared library.

Usage

has_cuML()

Value

A logical value indicating whether the current installation {cuda.ml} was linked to a valid version of the RAPIDS cuML shared library.

Examples


library(cuda.ml)

if (!has_cuML()) {
  warning(
    "Please install the RAPIDS cuML shared library first, and then re-",
    "install {cuda.ml}."
  )
}

cuda.ml documentation built on April 29, 2026, 5:10 p.m.