predict.cuda_ml_knn: Make predictions on new data points.

View source: R/knn.R

predict.cuda_ml_knnR Documentation

Make predictions on new data points.

Description

Make predictions on new data points using a cuML KNN model.

Usage

## S3 method for class 'cuda_ml_knn'
predict(object, new_data, type = NULL, ...)

Arguments

object

A trained CuML model.

new_data

A matrix or data frame containing new data points.

type

Type of prediction. Classification models support "class" and "prob"; regression models support "numeric". The default is "class" for classification and "numeric" for regression.

...

Additional arguments to predict(). Currently unused.

Value

Predictions on new data points.


cuda.ml documentation built on Aug. 21, 2026, 9:14 a.m.