| predict.cuda_ml_linear_model | R Documentation |
Make predictions on new data points using a linear model.
## S3 method for class 'cuda_ml_linear_model'
predict(object, new_data, ...)
object |
A trained CuML model. |
new_data |
A matrix or data frame containing new data points. |
... |
Additional arguments to |
Predictions on new data points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.