Skip to contents

Make predictions on new data points using a cuML SVM model.

Usage

# S3 method for class 'cuda_ml_svm'
predict(object, new_data, ...)

Arguments

object

A trained CuML model.

new_data

A matrix or data frame containing new data points.

...

Additional arguments to predict(). Currently unused.

Value

Predictions on new data points.