Skip to contents

Report native-backend metadata

Usage

cuda_ml_backend_info()

Value

A named list describing the selected backend and whether its exact cache is complete. This function performs read-only cache and inventory checks. It does not create or modify the cache, access the network, inspect an NVIDIA GPU or driver, or load the native backend.