| cuda_ml_cache_clean | R Documentation |
Removes downloaded and source-built runtime and backend cache generations, including the selected-backend record. Restart R before calling this function if the native backend has been loaded in this process.
cuda_ml_cache_clean()
Invisibly returns TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.