cuda_ml_inverse_transform: Apply the inverse transformation defined by a trained cuML...

View source: R/model.R

cuda_ml_inverse_transformR Documentation

Apply the inverse transformation defined by a trained cuML model.

Description

Given a trained cuML model, apply the inverse transformation defined by that model to an input dataset.

Usage

cuda_ml_inverse_transform(model, x, ...)

Arguments

model

A model object.

x

The dataset to be transformed.

...

Additional model-specific parameters (if any).

Value

The transformed data points.


cuda.ml documentation built on April 29, 2026, 5:10 p.m.