Build a specification for the "ivfpq" KNN query algorithm.
Source:R/knn.R
cuda_ml_knn_algo_ivfpq.RdBuild a specification of the inverted-file-product-quantization KNN query algorithm, with all required parameters specified explicitly.
R/knn.R
cuda_ml_knn_algo_ivfpq.RdBuild a specification of the inverted-file-product-quantization KNN query algorithm, with all required parameters specified explicitly.