| has_cuML | R Documentation |
Determine whether {cuda.ml} was linked to a valid version of the RAPIDS cuML shared library.
has_cuML()
A logical value indicating whether the current installation {cuda.ml} was linked to a valid version of the RAPIDS cuML shared library.
library(cuda.ml)
if (!has_cuML()) {
warning(
"Please install the RAPIDS cuML shared library first, and then re-",
"install {cuda.ml}."
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.