| predict.cuda_ml_knn | R Documentation |
Make predictions on new data points using a cuML KNN model.
## S3 method for class 'cuda_ml_knn'
predict(object, new_data, type = NULL, ...)
object |
A trained CuML model. |
new_data |
A matrix or data frame containing new data points. |
type |
Type of prediction. Classification models support
|
... |
Additional arguments to |
Predictions on new data points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.